==> localnews-quartz-service-1.0.9-sources.jar: com/bxm/localnews/quartz/service/impl/VideoShareServiceImpl.java <==
package com.bxm.localnews.quartz.service.impl;

import com.bxm.localnews.quartz.constant.RedisConfig;
import com.bxm.localnews.quartz.domain.VideoMapper;
import com.bxm.localnews.quartz.domain.VideoShareMapper;
import com.bxm.localnews.quartz.service.VideoShareService;
import com.bxm.localnews.quartz.vo.Video;
import com.bxm.localnews.quartz.vo.VideoShare;
import com.bxm.newidea.component.redis.KeyGenerator;
import com.bxm.newidea.component.redis.RedisListAdapter;
import com.bxm.newidea.component.service.BaseService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;

@Service
public class VideoShareServiceImpl extends BaseService implements VideoShareService {

    @Autowired
    private RedisListAdapter redisListAdapter;

    @Autowired
    private VideoShareMapper videoShareMapper;

    @Autowired
    private VideoMapper videoMapper;

    @Override
    public void videoShareConsume() {
        KeyGenerator keyGenerator = RedisConfig.VIDEO_QUEUE.copy().setKey("videoShareQueue");
        VideoShare videoShare = redisListAdapter.rightPop(keyGenerator, VideoShare.class);
        if (null != videoShare) {

            videoShare.setId(nextSequence());
            videoShare.setAddTime(new Date());
            videoShareMapper.insertSelective(videoShare);
            //更新新闻分享数量
            Video video = videoMapper.selectByPrimaryKey(videoShare.getVideoId());
            if (null != video) {
                Video videoUp = new Video();
                videoUp.setId(videoShare.getVideoId());
                videoUp.setShareCount(video.getShareCount() + 1);
                videoMapper.updateByPrimaryKeySelective(videoUp);
            }
        }
    }
}

==> localnews-quartz-service-1.1.0-sources.jar: com/bxm/localnews/quartz/service/impl/VideoShareServiceImpl.java <==
package com.bxm.localnews.quartz.service.impl;

import com.bxm.localnews.common.constant.RedisConfig;
import com.bxm.localnews.quartz.domain.VideoMapper;
import com.bxm.localnews.quartz.domain.VideoShareMapper;
import com.bxm.localnews.quartz.service.VideoShareService;
import com.bxm.localnews.quartz.vo.Video;
import com.bxm.localnews.quartz.vo.VideoShare;
import com.bxm.newidea.component.redis.KeyGenerator;
import com.bxm.newidea.component.redis.RedisListAdapter;
import com.bxm.newidea.component.service.BaseService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;

@Service
public class VideoShareServiceImpl extends BaseService implements VideoShareService {

    @Autowired
    private RedisListAdapter redisListAdapter;

    @Autowired
    private VideoShareMapper videoShareMapper;

    @Autowired
    private VideoMapper videoMapper;

    @Override
    public void videoShareConsume() {
        KeyGenerator keyGenerator = RedisConfig.VIDEO_QUEUE.copy().setKey("videoShareQueue");
        VideoShare videoShare = redisListAdapter.rightPop(keyGenerator, VideoShare.class);
        if (null != videoShare) {

            videoShare.setId(nextSequence());
            videoShare.setAddTime(new Date());
            videoShareMapper.insertSelective(videoShare);
            //更新新闻分享数量
            Video video = videoMapper.selectByPrimaryKey(videoShare.getVideoId());
            if (null != video) {
                Video videoUp = new Video();
                videoUp.setId(videoShare.getVideoId());
                videoUp.setShareCount(video.getShareCount()+1);
                videoMapper.updateByPrimaryKeySelective(videoUp);
            }
        }
    }
}
